@@ -62,7 +62,7 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
         self.api_update_replace_policies: Dict[str, Any] = {}
 
     @abstractmethod
-    def _process_api_events(  # noqa: too-many-arguments
+    def _process_api_events(  # noqa: PLR0913
         self,
         function: SamResource,
         api_events: Dict[str, Dict[str, Any]],
@@ -107,12 +107,13 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
             return
 
         implicit_api_resource = template.get(self.IMPLICIT_API_LOGICAL_ID)
-        globals_var = template.get_globals().get(SamResourceType(resource.type).name, {})
+        globals_var = template.get_globals().get(SamResourceType(resource.type).name) or {}
         should_propagate_tags = resource.properties.get("PropagateTags") or globals_var.get("PropagateTags")
+        tags_properties = resource.properties.get("Tags") or globals_var.get("Tags")
 
-        if implicit_api_resource and resource.properties.get("Tags") and should_propagate_tags:
+        if implicit_api_resource and tags_properties and should_propagate_tags:
             # This makes an assumption that the SAM resource has 'Tags' property and is a dictionary.
-            implicit_api_resource.properties.setdefault("Tags", {}).update(resource.properties["Tags"])
+            implicit_api_resource.properties.setdefault("Tags", {}).update(tags_properties)
             implicit_api_resource.properties["PropagateTags"] = True
 
     @cw_timer(prefix="Plugin-ImplicitApi")
@@ -482,7 +483,7 @@ class ImplicitApiPlugin(BasePlugin, Generic[T], metaclass=ABCMeta):
             sam_expect(method, event_id, "Method", is_sam_event=True).to_be_a_string(),
         )
 
-    def _update_resource_attributes_from_api_event(  # noqa: too-many-arguments
+    def _update_resource_attributes_from_api_event(  # noqa: PLR0913
         self,
         api_id: str,
         path: str,
